#
# spec file for package Regina-REXX
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define somajor 3
%define libname libregina%{somajor}
Name:           Regina-REXX
Version:        3.9.1
Release:        bp154.2.57
Summary:        Mark Hessling's implementation of the REXX Interpreter
License:        GFDL-1.1-only AND LGPL-2.1-or-later
URL:            http://regina-rexx.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/regina-rexx/regina-rexx/%{version}/Regina-REXX-%{version}.tar.gz
Source1:        http://sourceforge.net/projects/regina-rexx/files/regina-documentation/%{version}/regina.pdf#/Regina-REXX-%{version}-doc.pdf
Source2:        http://sourceforge.net/projects/regina-rexx/files/regina-documentation/%{version}/regutil.pdf#/Regina-REXX-regutil-%{version}-doc.pdf
Source3:        rxstack.service
BuildRequires:  distribution-release
BuildRequires:  flex
BuildRequires:  lsb-release
BuildRequires:  ncurses-devel
BuildRequires:  systemd-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       rexx
%{?systemd_ordering}

%description
Mark Hessling's implementation of the REXX language interpreter.

%package devel
Summary:        Header files for the REXX interpreter
Requires:       %{libname} = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Provides:       regina-devel = %{version}-%{release}
Provides:       regina:%{_includedir}/rexxsaa.h

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require Regina-REXX.

%package -n %{libname}
Summary:        The regina shared library

%description -n %{libname}
This package provides the shared library for Mark Hessling's implementation
of the REXX Interpreter.

%package doc
Summary:        Documentation for the Regina REXX interpreter

%description doc
Documentation for both the Regina REXX interpreter and the REXX Utility
Functions (regutil).

%prep
%setup -q

%build
%configure \
  --enable-posix-threads
# parallel build seems to randomly fail
make --jobs=1

%install
%make_install
# The supplied init script isn't sufficient for our needs.
rm -v %{buildroot}%{_sysconfdir}/rxstack
install -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/rxstack.service
cp %{SOURCE1} .
cp %{SOURCE2} .
# Do not ship statical library
rm -f %{buildroot}%{_libdir}/libregina.a

install -m 755 -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcrxstack
ln -s %{_mandir}/man1/regina.1.gz %{buildroot}/%{_mandir}/man1/rexx.1.gz

# adding update-alternatives support (boo#1083875)
install -d %{buildroot}%{_sysconfdir}/alternatives

touch %{buildroot}%{_sysconfdir}/alternatives/rexx
touch %{buildroot}%{_sysconfdir}/alternatives/rxqueue

mv %{buildroot}%{_bindir}/rexx %{buildroot}%{_bindir}/rexx-%{name}
mv %{buildroot}%{_bindir}/rxqueue %{buildroot}%{_bindir}/rxqueue-%{name}

ln -sf %{_sysconfdir}/alternatives/rexx %{buildroot}%{_bindir}/rexx
ln -sf %{_sysconfdir}/alternatives/rxqueue %{buildroot}%{_bindir}/rxqueue

# Drop not needed examples/addons
rm -rf  %{buildroot}%{_datadir}/Regina-REXX/addons

%pre
%service_add_pre rxstack.service

%post
%service_add_post rxstack.service
update-alternatives --install \
   %{_bindir}/rexx rexx %{_bindir}/rexx-%{name} 15
update-alternatives --install \
   %{_bindir}/rxqueue rxqueue %{_bindir}/rxqueue-%{name} 15

%preun
%service_del_preun rxstack.service

%postun
%service_del_postun rxstack.service
if [ ! -f %{_bindir}/rexx ] ; then
   update-alternatives --remove rexx %{_bindir}/rexx-%{name}
fi
if [ ! -f %{_bindir}/rxqueue ] ; then
   update-alternatives --remove rxqueue %{_bindir}/rxqueue-%{name}
fi

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_mandir}/man1/*
%doc COPYING-LIB README.*
%ghost %{_sysconfdir}/alternatives/rexx
%ghost %{_sysconfdir}/alternatives/rxqueue
%{_bindir}/regina
%{_bindir}/rexx
%{_bindir}/rexx-%{name}
%{_bindir}/rxqueue
%{_bindir}/rxqueue-%{name}
%{_bindir}/rxstack
%{_datadir}/Regina-REXX
%{_sbindir}/rcrxstack
%{_unitdir}/rxstack.service

%files doc
%doc Regina-REXX-%{version}-doc.pdf Regina-REXX-regutil-%{version}-doc.pdf

%files devel
%{_bindir}/regina-config
%{_includedir}/*
%{_libdir}/libregina.so

%files -n %{libname}
%{_libdir}/libregina.so.%{somajor}*

%changelog
* Tue Jul 27 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Modified:
  * rxstack.service
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Reduce %%systemd_requires to %%systemd_ordering:
  %%service_* can deal with the absence of systemd.
- Replace historic boilerplate -devel subpackage summary.
* Thu Mar 15 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
- Allow alternative rexx implementations to be installed in
  parallel (bsc#1083875)
* Thu Jun  8 2017 mpluskal@suse.com
- Update dependencies
* Mon May  2 2016 mpluskal@suse.com
- Rename package to Regina-REXX
* Wed Apr 20 2016 mpost@suse.com
- Upgraded to version 3.9.1
- Added Regina-REXX-regutil-3.9.1-doc.pdf
- Removed regina-rxstack-lsb.init.d and added a systemd unit file
  for rxstack.
- Converted all hardcoded paths to RPM macros.
- Removed obsolete regina-rpmlintrc file
- Removed the following obsolete patches:
  regina-3.3-configure.diff
  regina-3.3-Makefile.in.diff
- Removed deprecated Authors section
- Broke the documentation out into a separate package.
- Removed redundant changelog entries from the spec file.
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Thu Aug 12 2004 mge@suse.de
- update to 3.3
* Mon Feb  9 2004 mge@suse.de
- added SONAME (libregina.so) to library
* Tue Aug  5 2003 mge@suse.de
- update to 3.2
* Sun Jun 15 2003 mmj@suse.de
- Package all dirs
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Aug 20 2002 mge@suse.de
- fix dependencies (remove BuildRoot from installed scripts)
* Fri Aug 16 2002 mge@suse.de
- fix building on 64bit
* Thu Aug 15 2002 mge@suse.de
- update to 3.0
* Tue May 21 2002 coolo@suse.de
- use %%_libdir
* Fri Jun 15 2001 schwab@suse.de
- Fix for new autoconf.
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Mon Sep 18 2000 schwab@suse.de
- Use alpha patch on ia64 and lower opt level.
* Thu Sep 14 2000 ro@suse.de
- update to 2.1
- fix for alpha
* Wed Jul  5 2000 mge@suse.de
- Update to regina 2.0.0
* Mon Feb 14 2000 mge@suse.de
- patched Makefile.in to make mandir valid
* Mon Feb 14 2000 mge@suse.de
- fixed mandir
* Sun Feb 13 2000 mge@suse.de
- update to 0.8h
- group tag
- use version macro
* Mon Oct 25 1999 mge@suse.de
- initial SuSE-RPM
